@@ -1,4 +1,4 @@
-/*-
+/*-F
  * Copyright (c) 2004-2007 os-cillation e.K.
  *
  * Written by Benedikt Meurer <benny@xfce.org>.
@@ -266,11 +266,6 @@ main (int argc, char **argv)
     nargv[nargc++] = g_strdup (argv[n]);
   nargv[nargc] = NULL;
 
-#if !GLIB_CHECK_VERSION (2, 36, 0)
-  /* for GDBus */
-  g_type_init ();
-#endif
-
   if (!options.disable_server)
     {
       /* try to connect to an existing Terminal service */
@@ -323,7 +318,7 @@ main (int argc, char **argv)
   gtk_init (&argc, &argv);
 
   /* set default window icon */
-  gtk_window_set_default_icon_name ("utilities-terminal");
+  gtk_window_set_default_icon_name ("org.xfce.terminal");
 
   app = g_object_new (TERMINAL_TYPE_APP, NULL);
 
