@@ -678,11 +678,6 @@ terminal_app_find_screen (GdkDisplay *display,
 
   if (display != NULL)
     {
-#if !GTK_CHECK_VERSION (3, 20, 0)
-      if (screen_num >= 0)
-        screen = gdk_display_get_screen (display, screen_num);
-#endif
-
       if (screen == NULL)
         screen = gdk_display_get_default_screen (display);
 
@@ -900,13 +895,8 @@ terminal_app_open_window (TerminalApp        *app,
       if ((mask & XValue) || (mask & YValue))
         {
           screen = gtk_window_get_screen (GTK_WINDOW (window));
-  #if GTK_CHECK_VERSION (3, 22, 0)
           gdk_window_get_geometry (gdk_screen_get_root_window (screen), NULL, NULL,
                                    &screen_width, &screen_height);
-  #else
-          screen_width = gdk_screen_get_width (screen);
-          screen_height = gdk_screen_get_height (screen);
-  #endif
           gtk_window_get_size (GTK_WINDOW (window), &window_width, &window_height);
           if (mask & XNegative)
             {
