@@ -128,22 +128,6 @@ terminal_option_show_hide_cmp (const gchar         *long_name,
 
 
 
-static void
-terminal_tab_attr_free (TerminalTabAttr *attr)
-{
-  terminal_return_if_fail (attr != NULL);
-
-  g_strfreev (attr->command);
-  g_free (attr->directory);
-  g_free (attr->title);
-  g_free (attr->initial_title);
-  g_free (attr->color_text);
-  g_free (attr->color_bg);
-  g_slice_free (TerminalTabAttr, attr);
-}
-
-
-
 void
 terminal_options_parse (gint              argc,
                         gchar           **argv,
@@ -162,15 +146,15 @@ terminal_options_parse (gint              argc,
         break;
 
       if (terminal_option_cmp ("help", 'h', argc, argv, &n, NULL))
-        options->show_help = TRUE;
+        options->show_help = 1;
       else if (terminal_option_cmp ("version", 'V', argc, argv, &n, NULL))
-        options->show_version = TRUE;
+        options->show_version = 1;
       else if (terminal_option_cmp ("disable-server", 0, argc, argv, &n, NULL))
-        options->disable_server = TRUE;
+        options->disable_server = 1;
       else if (terminal_option_cmp ("color-table", 0, argc, argv, &n, NULL))
-        options->show_colors = TRUE;
+        options->show_colors = 1;
       else if (terminal_option_cmp ("preferences", 0, argc, argv, &n, NULL))
-        options->show_preferences = TRUE;
+        options->show_preferences = 1;
     }
 }
 
@@ -527,7 +511,7 @@ terminal_window_attr_parse (gint              argc,
           else
             {
               /* add new tab */
-              tab_attr = g_slice_new0 (TerminalTabAttr);
+              tab_attr = terminal_tab_attr_new ();
               win_attr->tabs = g_slist_append (win_attr->tabs, tab_attr);
             }
         }
@@ -636,26 +620,57 @@ failed:
 TerminalWindowAttr*
 terminal_window_attr_new (void)
 {
-  TerminalWindowAttr *win_attr;
-  TerminalTabAttr    *tab_attr;
+  TerminalWindowAttr *win_attr = g_slice_new0 (TerminalWindowAttr);
 
-  win_attr = g_slice_new0 (TerminalWindowAttr);
   win_attr->fullscreen = FALSE;
   win_attr->menubar = TERMINAL_VISIBILITY_DEFAULT;
   win_attr->borders = TERMINAL_VISIBILITY_DEFAULT;
   win_attr->toolbar = TERMINAL_VISIBILITY_DEFAULT;
   win_attr->scrollbar = TERMINAL_VISIBILITY_DEFAULT;
   win_attr->zoom = TERMINAL_ZOOM_LEVEL_DEFAULT;
-
-  tab_attr = g_slice_new0 (TerminalTabAttr);
-  tab_attr->dynamic_title_mode = TERMINAL_TITLE_DEFAULT;
-  win_attr->tabs = g_slist_prepend (NULL, tab_attr);
+  win_attr->tabs = g_slist_prepend (NULL, terminal_tab_attr_new ());
 
   return win_attr;
 }
 
 
 
+/**
+ **/
+TerminalTabAttr*
+terminal_tab_attr_new (void)
+{
+  TerminalTabAttr *tab_attr = g_slice_new0 (TerminalTabAttr);
+
+  tab_attr->dynamic_title_mode = TERMINAL_TITLE_DEFAULT;
+  tab_attr->position = -1;
+
+  return tab_attr;
+}
+
+
+
+/**
+ * terminal_tab_attr_free:
+ * @attr  : A #TerminalTabAttr.
+ **/
+void
+terminal_tab_attr_free (TerminalTabAttr *attr)
+{
+  terminal_return_if_fail (attr != NULL);
+
+  g_strfreev (attr->command);
+  g_free (attr->directory);
+  g_free (attr->title);
+  g_free (attr->initial_title);
+  g_free (attr->color_text);
+  g_free (attr->color_bg);
+  g_free (attr->color_title);
+  g_slice_free (TerminalTabAttr, attr);
+}
+
+
+
 /**
  * terminal_window_attr_free:
  * @attr  : A #TerminalWindowAttr.
