@@ -34,7 +34,7 @@
 #include <terminal/terminal-encoding-action.h>
 #include <terminal/terminal-private.h>
 
-
+#include "terminal-preferences-ui.h"
 
 static void     terminal_preferences_dialog_finalize          (GObject                   *object);
 static void     terminal_preferences_dialog_disc_bindings     (GtkWidget                 *widget,
@@ -74,6 +74,9 @@ static void     terminal_preferences_dialog_background_set    (GtkFileChooserBut
                                                                TerminalPreferencesDialog *dialog);
 static void     terminal_preferences_dialog_encoding_changed  (GtkComboBox               *combobox,
                                                                TerminalPreferencesDialog *dialog);
+static gboolean monospace_filter                              (const PangoFontFamily     *family,
+                                                               const PangoFontFace       *face,
+                                                               gpointer                   data);
 
 
 
@@ -158,8 +161,6 @@ terminal_preferences_dialog_init (TerminalPreferencesDialog *dialog)
   GObject          *object, *object2;
   gchar             palette_name[16];
   GtkFileFilter    *filter;
-  gchar            *file;
-  guint             res;
   GBinding         *binding;
   GtkTreeModel     *model;
   gchar            *current;
@@ -200,28 +201,12 @@ terminal_preferences_dialog_init (TerminalPreferencesDialog *dialog)
 
   dialog->preferences = terminal_preferences_get ();
 
-  /* lookup the ui file */
-  xfce_resource_push_path (XFCE_RESOURCE_DATA, DATADIR);
-  file = xfce_resource_lookup (XFCE_RESOURCE_DATA, "xfce4/terminal/terminal-preferences.ui");
-  xfce_resource_pop_path (XFCE_RESOURCE_DATA);
-
-  if (G_UNLIKELY (file == NULL))
-    {
-      g_set_error (&error, 0, 0, "file not found");
-      goto error;
-    }
-
-  /* load the builder data into the object */
-  res = gtk_builder_add_from_file (GTK_BUILDER (dialog), file, &error);
-  g_free (file);
-
-  if (res == 0)
-    {
-error:
-      g_critical ("Failed to load ui file: %s.", error->message);
+  if (!gtk_builder_add_from_string (GTK_BUILDER (dialog), terminal_preferences_ui,
+                                    terminal_preferences_ui_length, &error)) {
+      g_critical ("Error loading UI: %s", error->message);
       g_error_free (error);
       return;
-    }
+  }
 
   /* connect response to dialog */
   object = gtk_builder_get_object (GTK_BUILDER (dialog), "dialog");
@@ -257,10 +242,8 @@ error:
       g_signal_connect (object, "color-set",
           G_CALLBACK (terminal_preferences_dialog_palette_changed), dialog);
 
-#if GTK_CHECK_VERSION (3, 20, 0)
       /* don't show palette when editing colors */
       g_object_set (object, "show-editor", TRUE, NULL);
-#endif
     }
 
   /* watch color changes in property */
@@ -365,6 +348,7 @@ error:
   object = gtk_builder_get_object (GTK_BUILDER (dialog), "font-use-system");
   object2 = gtk_builder_get_object (GTK_BUILDER (dialog), "font-name");
   terminal_return_if_fail (G_IS_OBJECT (object) && G_IS_OBJECT (object2));
+  gtk_font_chooser_set_filter_func (GTK_FONT_CHOOSER (object2), monospace_filter, NULL, NULL);
   g_object_bind_property (object, "active",
                           object2, "sensitive",
                           G_BINDING_INVERT_BOOLEAN | G_BINDING_SYNC_CREATE);
@@ -557,7 +541,6 @@ static gboolean
 terminal_preferences_dialog_color_press_event (GtkWidget      *widget,
                                                GdkEventButton *event)
 {
-#if GTK_CHECK_VERSION (3, 20, 0)
   gboolean show_editor;
 
   if (event->type == GDK_BUTTON_PRESS && event->button == 1 && event->state == GDK_CONTROL_MASK)
@@ -569,7 +552,6 @@ terminal_preferences_dialog_color_press_event (GtkWidget      *widget,
       g_object_set (G_OBJECT (widget), "show-editor", show_editor, NULL);
       return TRUE;
     }
-#endif
 
   return FALSE;
 }
@@ -1124,6 +1106,16 @@ terminal_preferences_dialog_encoding_changed (GtkComboBox               *combobo
 
 
 
+static gboolean
+monospace_filter (const PangoFontFamily *family,
+                  const PangoFontFace   *face,
+                  gpointer data)
+{
+  return pango_font_family_is_monospace ((PangoFontFamily *) family);
+}
+
+
+
 /**
  * terminal_preferences_dialog_new:
  *
