@@ -165,7 +165,8 @@ static void       terminal_screen_set_tab_label_color           (TerminalScreen
 static GtkWidget* terminal_screen_unsafe_paste_dialog_new       (TerminalScreen        *screen,
                                                                  const gchar           *text);
 static void       terminal_screen_paste_unsafe_text             (TerminalScreen        *screen,
-                                                                 const gchar           *text);
+                                                                 const gchar           *text,
+                                                                 GdkAtom                original_clipboard);
 
 
 
@@ -1176,9 +1177,7 @@ terminal_screen_update_colors (TerminalScreen *screen)
   if (!cursor_use_default)
     {
       cursor_use_default = !terminal_preferences_get_color (screen->preferences, "color-cursor-foreground", &cursor);
-#if VTE_CHECK_VERSION (0, 44, 0)
       vte_terminal_set_color_cursor_foreground (VTE_TERMINAL (screen->terminal), cursor_use_default ? NULL : &cursor);
-#endif
       cursor_use_default = !terminal_preferences_get_color (screen->preferences, "color-cursor", &cursor);
       vte_terminal_set_color_cursor (VTE_TERMINAL (screen->terminal), cursor_use_default ? NULL : &cursor);
     }
@@ -1376,9 +1375,7 @@ terminal_screen_update_word_chars (TerminalScreen *screen)
   g_object_get (G_OBJECT (screen->preferences), "word-chars", &word_chars, NULL);
   if (G_LIKELY (word_chars != NULL))
     {
-#if VTE_CHECK_VERSION (0, 40, 0)
       vte_terminal_set_word_char_exceptions (VTE_TERMINAL (screen->terminal), word_chars);
-#endif
       g_free (word_chars);
     }
 }
@@ -1789,10 +1786,14 @@ terminal_screen_unsafe_paste_dialog_new (TerminalScreen *screen,
 
 static void
 terminal_screen_paste_unsafe_text (TerminalScreen *screen,
-                                   const gchar    *text)
+                                   const gchar    *text,
+                                   GdkAtom         original_clipboard)
 {
-  GtkWidget *dialog = terminal_screen_unsafe_paste_dialog_new (screen, text);
+  GtkWidget *dialog;
 
+  terminal_return_if_fail (original_clipboard != GDK_SELECTION_CLIPBOARD && original_clipboard != GDK_SELECTION_PRIMARY);
+
+  dialog = terminal_screen_unsafe_paste_dialog_new (screen, text);
   gtk_widget_show_all (dialog);
   /* set focus to the Paste button */
   gtk_widget_grab_focus (gtk_dialog_get_widget_for_response (GTK_DIALOG (dialog), GTK_RESPONSE_YES));
@@ -1811,14 +1812,21 @@ terminal_screen_paste_unsafe_text (TerminalScreen *screen,
 
       if (res_text != NULL)
         {
-          /* convert LF to CR before feeding: see https://gitlab.gnome.org/GNOME/vte/issues/106 */
-          size_t i;
-          for (i = 0; i < strlen (res_text); ++i)
-            if (res_text[i] == '\x0A')
-              res_text[i] = '\x0D';
-
-          vte_terminal_feed_child (VTE_TERMINAL (screen->terminal), res_text, strlen (res_text));
+          /* Modify the content of the clipboard as required, and then paste it.
+           * Using the builtin pasting function enables bracketed paste mode when applicable.
+           */
+          GtkClipboard *clipboard = gtk_clipboard_get (original_clipboard);
+          gtk_clipboard_set_text (clipboard, res_text, strlen (res_text));
           g_free (res_text);
+
+          if (original_clipboard == GDK_SELECTION_CLIPBOARD) {
+            vte_terminal_paste_clipboard (VTE_TERMINAL (screen->terminal));
+          } else {
+            vte_terminal_paste_primary (VTE_TERMINAL (screen->terminal));
+          }
+
+          /* restore original clipboard contents */
+          gtk_clipboard_set_text (clipboard, text, strlen (text));
         }
     }
 
@@ -1915,7 +1923,7 @@ terminal_screen_launch_child (TerminalScreen *screen)
   gchar       **argv2;
   guint         i, argc;
   VtePtyFlags   pty_flags = VTE_PTY_DEFAULT;
-  GSpawnFlags   spawn_flags = G_SPAWN_CHILD_INHERITS_STDIN | G_SPAWN_SEARCH_PATH;
+  GSpawnFlags   spawn_flags = G_SPAWN_SEARCH_PATH;
 
   terminal_return_if_fail (TERMINAL_IS_SCREEN (screen));
 
@@ -2108,22 +2116,17 @@ terminal_screen_set_window_geometry_hints (TerminalScreen *screen,
 {
   GdkGeometry    hints;
   glong          char_width, char_height;
-#if GTK_CHECK_VERSION (3, 19, 5)
   GtkRequisition vbox_request;
   GtkAllocation  toplevel_allocation, vbox_allocation;
   glong          grid_width, grid_height;
   glong          chrome_width, chrome_height;
   gint           csd_width, csd_height;
-#else
-  gint           xpad, ypad;
-#endif
 
   terminal_return_if_fail (TERMINAL_IS_SCREEN (screen));
   terminal_return_if_fail (VTE_IS_TERMINAL (screen->terminal));
   terminal_return_if_fail (gtk_widget_get_realized (GTK_WIDGET (screen)));
   terminal_return_if_fail (gtk_widget_get_realized (GTK_WIDGET (window)));
 
-#if GTK_CHECK_VERSION (3, 19, 5)
   terminal_screen_get_geometry (screen, &char_width, &char_height, NULL, NULL);
   terminal_screen_get_size (screen, &grid_width, &grid_height);
 
@@ -2138,12 +2141,6 @@ terminal_screen_set_window_geometry_hints (TerminalScreen *screen,
 
   hints.base_width = chrome_width + csd_width;
   hints.base_height = chrome_height + csd_height;
-#else
-  terminal_screen_get_geometry (screen, &char_width, &char_height, &xpad, &ypad);
-
-  hints.base_width = xpad;
-  hints.base_height = ypad;
-#endif
 
   hints.width_inc = char_width;
   hints.height_inc = char_height;
@@ -2151,11 +2148,7 @@ terminal_screen_set_window_geometry_hints (TerminalScreen *screen,
   hints.min_height = hints.base_height + hints.height_inc * MIN_ROWS;
 
   gtk_window_set_geometry_hints (window,
-#if GTK_CHECK_VERSION (3, 19, 5)
                                  NULL,
-#else
-                                 screen->terminal,
-#endif
                                  &hints,
                                  GDK_HINT_RESIZE_INC
                                  | GDK_HINT_MIN_SIZE
@@ -2458,7 +2451,7 @@ terminal_screen_paste_clipboard (TerminalScreen *screen)
   g_object_get (G_OBJECT (screen->preferences), "misc-show-unsafe-paste-dialog", &show_dialog, NULL);
 
   if (show_dialog && terminal_screen_is_text_unsafe (text))
-    terminal_screen_paste_unsafe_text (screen, text);
+    terminal_screen_paste_unsafe_text (screen, text, GDK_SELECTION_CLIPBOARD);
   else
     vte_terminal_paste_clipboard (VTE_TERMINAL (screen->terminal));
 
@@ -2487,7 +2480,7 @@ terminal_screen_paste_primary (TerminalScreen *screen)
   g_object_get (G_OBJECT (screen->preferences), "misc-show-unsafe-paste-dialog", &show_dialog, NULL);
 
   if (show_dialog && terminal_screen_is_text_unsafe (text))
-    terminal_screen_paste_unsafe_text (screen, text);
+    terminal_screen_paste_unsafe_text (screen, text, GDK_SELECTION_PRIMARY);
   else
     vte_terminal_paste_primary (VTE_TERMINAL (screen->terminal));
 
@@ -2526,7 +2519,7 @@ terminal_screen_reset (TerminalScreen *screen,
   vte_terminal_reset (VTE_TERMINAL (screen->terminal), TRUE, clear);
 
   if (clear)
-    vte_terminal_search_set_gregex (VTE_TERMINAL (screen->terminal), NULL, 0);
+    vte_terminal_search_set_regex (VTE_TERMINAL (screen->terminal), NULL, 0);
 }
 
 
@@ -2624,11 +2617,7 @@ terminal_screen_get_tab_label (TerminalScreen *screen)
   gtk_widget_set_has_tooltip (screen->tab_label, TRUE);
 
   button = gtk_button_new ();
-#if GTK_CHECK_VERSION (3,20,0)
   gtk_widget_set_focus_on_click (button, FALSE);
-#else
-  gtk_button_set_focus_on_click (GTK_BUTTON (button), FALSE);
-#endif
   gtk_button_set_relief (GTK_BUTTON (button), GTK_RELIEF_NONE);
   gtk_widget_set_can_focus (button, FALSE);
   gtk_widget_set_can_default (button, FALSE);
@@ -2692,11 +2681,11 @@ terminal_screen_set_encoding (TerminalScreen *screen,
 
 void
 terminal_screen_search_set_gregex (TerminalScreen *screen,
-                                   GRegex         *regex,
+                                   VteRegex       *regex,
                                    gboolean        wrap_around)
 {
   terminal_return_if_fail (TERMINAL_IS_SCREEN (screen));
-  vte_terminal_search_set_gregex (VTE_TERMINAL (screen->terminal), regex, 0);
+  vte_terminal_search_set_regex (VTE_TERMINAL (screen->terminal), regex, 0);
   vte_terminal_search_set_wrap_around (VTE_TERMINAL (screen->terminal), wrap_around);
 }
 
@@ -2706,7 +2695,7 @@ gboolean
 terminal_screen_search_has_gregex (TerminalScreen *screen)
 {
   terminal_return_val_if_fail (TERMINAL_IS_SCREEN (screen), FALSE);
-  return vte_terminal_search_get_gregex (VTE_TERMINAL (screen->terminal)) != NULL;
+  return vte_terminal_search_get_regex (VTE_TERMINAL (screen->terminal)) != NULL;
 }
 
 
